@@ -1,6 +1,6 @@
 /*
    This file is part of GNUnet.
-   Copyright (C) 2022--2023 GNUnet e.V.
+   Copyright (C) 2022--2025 GNUnet e.V.
 
    GNUnet is free software: you can redistribute it and/or modify it
    under the terms of the GNU Affero General Public License as published
@@ -29,6 +29,7 @@
 
 #include "text_input.h"
 #include "../application.h"
+#include "../util.h"
 
 void
 chat_open_dialog_event(UI_CHAT_OPEN_DIALOG_Handle *open_dialog,
@@ -43,12 +44,24 @@ chat_open_dialog_event(UI_CHAT_OPEN_DIALOG_Handle *open_dialog,
       break;
     case '\n':
     case KEY_ENTER:
+    {
       if (open_dialog->topic_len > 0)
-	GNUNET_CHAT_group_create(app->chat.handle, open_dialog->topic);
+      {
+        struct GNUNET_CHAT_Group *group;
+        char *group_name = malloc(open_dialog->topic_len + 2);
+
+        group = GNUNET_CHAT_group_create(app->chat.handle, open_dialog->topic);
+        group_name[0] = '#';
+        memcpy(group_name + 1, open_dialog->topic, open_dialog->topic_len + 1);
+
+        GNUNET_CHAT_group_set_name(group, group_name);
+        free(group_name);
+      }
 
       open_dialog->topic_len = 0;
       open_dialog->window = NULL;
       break;
+    }
     default:
       break;
   }
@@ -67,8 +80,18 @@ chat_open_dialog_print(UI_CHAT_OPEN_DIALOG_Handle *open_dialog)
   werase(window);
   wmove(window, 0, 0);
 
+  util_print_prompt(window, "Enter the topic of the public chat:");
+  wmove(window, 1, 0);
+
+  wprintw(window, "> ");
+  wmove(window, 1, 2);
+
+  wattron(window, A_BOLD);
+
   wprintw(window, "%s", open_dialog->topic);
-  wmove(window, 0, open_dialog->topic_pos);
+  wmove(window, 1, 2 + open_dialog->topic_pos);
+
+  wattroff(window, A_BOLD);
 
   wcursyncup(window);
   curs_set(1);
