@@ -1,6 +1,6 @@
 /*
    This file is part of GNUnet.
-   Copyright (C) 2022--2023 GNUnet e.V.
+   Copyright (C) 2022--2025 GNUnet e.V.
 
    GNUnet is free software: you can redistribute it and/or modify it
    under the terms of the GNU Affero General Public License as published
@@ -29,6 +29,7 @@
 
 #include "text_input.h"
 #include "../application.h"
+#include "../util.h"
 
 void
 lobby_enter_dialog_event(UI_LOBBY_ENTER_DIALOG_Handle *enter_dialog,
@@ -86,15 +87,25 @@ lobby_enter_dialog_print(UI_LOBBY_ENTER_DIALOG_Handle *enter_dialog)
   werase(window);
   wmove(window, 0, 0);
 
+  util_print_prompt(window, "Enter the URI of the lobby:");
+  wmove(window, 1, 0);
+
+  wprintw(window, "> ");
+  wmove(window, 1, 2);
+
+  wattron(window, A_BOLD);
   wprintw(window, "%s", enter_dialog->uri);
+  wattroff(window, A_BOLD);
 
   if (enter_dialog->error)
   {
-    wmove(window, 1, 0);
+    wmove(window, 2, 0);
     wprintw(window, "ERROR: %s", enter_dialog->error);
   }
 
-  wmove(window, 0, enter_dialog->uri_pos);
+  wattron(window, A_BOLD);
+  wmove(window, 1, 2 + enter_dialog->uri_pos);
+  wattroff(window, A_BOLD);
 
   wcursyncup(window);
   curs_set(1);
